@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: dwtrace.c 8489 2008-01-17 13:47:11Z leonardo $ */
+/* $Id: dwtrace.c 8604 2008-03-21 05:07:53Z leonardo $ */
 /* Graphical trace server for Windows */
 
 /*  This module use Win32-specific API.
@@ -332,7 +332,7 @@ static void dw_gt_set_origin(vd_trace_interface *I)
 #    define SET_CALLBACK(I,a) I.a = 0
 #endif
 
-void visual_tracer_init(void)
+vd_trace_interface *visual_tracer_init(void)
 {   SET_CALLBACK(visual_tracer, get_dc);
     SET_CALLBACK(visual_tracer, release_dc);
     SET_CALLBACK(visual_tracer, erase);
@@ -357,6 +357,7 @@ void visual_tracer_init(void)
     SET_CALLBACK(visual_tracer, set_scale);
     SET_CALLBACK(visual_tracer, set_shift);
     SET_CALLBACK(visual_tracer, set_origin);
+    return &visual_tracer;
 }
         
 void visual_tracer_close(void)
