@@ -1,22 +1,17 @@
-/* Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999 artofcode LLC.  All rights reserved.
+/* Copyright (C) 2001-2006 Artifex Software, Inc.
+   All Rights Reserved.
   
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by the
-  Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA, 02111-1307.
+   This software is provided AS-IS with no warranty, either express or
+   implied.
 
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/
+   or contact Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134,
+   San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/*$Id: gdevxalt.c,v 1.2.6.2.2.1 2003/01/17 00:49:02 giles Exp $ */
+/* $Id: gdevxalt.c 8250 2007-09-25 13:31:24Z giles $ */
 /* Alternative X Windows drivers for help in driver debugging */
 #include "gx.h"			/* for gx_bitmap; includes std.h */
 #include "math_.h"
@@ -30,6 +25,7 @@
 #include "gdevx.h"
 
 extern const gx_device_X gs_x11_device;
+extern const gx_device_X gs_x11alpha_device;
 
 /*
  * Define a forwarding device with a cache for the first 16 colors,
@@ -59,15 +55,13 @@ gs_private_st_suffix_add0_final(st_device_X_wrapper, gx_device_X_wrapper,
 /* ---------------- Generic procedures ---------------- */
 
 /* Forward declarations */
-private int get_dev_target(P2(gx_device **, gx_device *));
+static int get_dev_target(gx_device **, gx_device *);
 
-#define set_dev_target(tdev, dev)\
-  return_if_error(get_dev_target(&tdev, dev))
-private int get_target_info(P1(gx_device *));
-private gx_color_index x_alt_map_color(P2(gx_device *, gx_color_index));
+static int get_target_info(gx_device *);
+static gx_color_index x_alt_map_color(gx_device *, gx_color_index);
 
 /* Clear the color mapping cache. */
-private void
+static void
 x_clear_color_cache(gx_device /*gx_device_X_wrapper */  * dev)
 {
     gx_device_X_wrapper *xdev = (gx_device_X_wrapper *) dev;
@@ -80,13 +74,14 @@ x_clear_color_cache(gx_device /*gx_device_X_wrapper */  * dev)
 
 /* "Wrappers" for driver procedures */
 
-private int
+static int
 x_wrap_open(gx_device * dev)
 {
     gx_device *tdev;
     int rcode, code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     rcode = (*dev_proc(tdev, open_device)) (tdev);
     if (rcode < 0)
 	return rcode;
@@ -95,25 +90,29 @@ x_wrap_open(gx_device * dev)
     return (code < 0 ? code : rcode);
 }
 
-private int
+static int
 x_forward_sync_output(gx_device * dev)
 {
     gx_device *tdev;
+    int code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     return (*dev_proc(tdev, sync_output)) (tdev);
 }
 
-private int
+static int
 x_forward_output_page(gx_device * dev, int num_copies, int flush)
 {
     gx_device *tdev;
+    int code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     return (*dev_proc(tdev, output_page)) (tdev, num_copies, flush);
 }
 
-private int
+static int
 x_wrap_close(gx_device * dev)
 {
     /*
@@ -126,38 +125,44 @@ x_wrap_close(gx_device * dev)
     return 0;
 }
 
-private int
+static int
 x_wrap_map_color_rgb(gx_device * dev, gx_color_index color,
 		     gx_color_value prgb[3])
 {
     gx_device *tdev;
+    int code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     return (*dev_proc(tdev, map_color_rgb)) (tdev,
 					     x_alt_map_color(dev, color),
 					     prgb);
 }
 
-private int
+static int
 x_wrap_fill_rectangle(gx_device * dev, int x, int y, int w, int h,
 		      gx_color_index color)
 {
     gx_device *tdev;
+    int code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     return (*dev_proc(tdev, fill_rectangle)) (tdev, x, y, w, h,
 					      x_alt_map_color(dev, color));
 }
 
-private int
+static int
 x_wrap_copy_mono(gx_device * dev,
 		 const byte * base, int sourcex, int raster, gx_bitmap_id id,
 		 int x, int y, int w, int h,
 		 gx_color_index zero, gx_color_index one)
 {
     gx_device *tdev;
+    int code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     return (*dev_proc(tdev, copy_mono)) (tdev, base, sourcex, raster, id,
 					 x, y, w, h,
 					 x_alt_map_color(dev, zero),
@@ -165,7 +170,7 @@ x_wrap_copy_mono(gx_device * dev,
 
 }
 
-private int
+static int
 x_wrap_copy_color(gx_device * dev, const byte * base, int sourcex,
 		  int raster, gx_bitmap_id id, int x, int y, int w, int h)
 {
@@ -176,9 +181,11 @@ x_wrap_copy_color(gx_device * dev, const byte * base, int sourcex,
     int block_w, block_h;
     int xblock, yblock;
     byte mapped[mapped_bytes];
+    int code;
 
     fit_copy(dev, base, sourcex, raster, id, x, y, w, h);
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     /* Device pixels must be an integral number of bytes. */
     if (tdev->color_info.depth & 7)
 	return gx_default_copy_color(dev, base, sourcex, raster, id,
@@ -234,27 +241,31 @@ x_wrap_copy_color(gx_device * dev, const byte * base, int sourcex,
 }
 
 
-private int
+static int
 x_forward_copy_color(gx_device * dev, const byte * base, int sourcex,
 		     int raster, gx_bitmap_id id, int x, int y, int w, int h)
 {
     gx_device *tdev;
+    int code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     return (*dev_proc(tdev, copy_color)) (tdev, base, sourcex, raster, id,
 					  x, y, w, h);
 }
 
-private int
+static int
 x_forward_get_bits(gx_device * dev, int y, byte * str, byte ** actual_data)
 {
     gx_device *tdev;
+    int code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     return (*dev_proc(tdev, get_bits)) (tdev, y, str, actual_data);
 }
 
-private int
+static int
 x_wrap_get_bits(gx_device * dev, int y, byte * str, byte ** actual_data)
 {
     int depth = dev->color_info.depth;
@@ -281,7 +292,8 @@ x_wrap_get_bits(gx_device * dev, int y, byte * str, byte ** actual_data)
 
     DECLARE_LINE_ACCUM(str, depth, 0);
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     width = tdev->width;
     sdepth = tdev->color_info.depth;
     smask = (sdepth <= 8 ? (1 << sdepth) - 1 : 0xff);
@@ -309,8 +321,7 @@ x_wrap_get_bits(gx_device * dev, int y, byte * str, byte ** actual_data)
 	    (*dev_proc(tdev, map_color_rgb))(tdev, pixel, rgb);
 	    pixel_in = pixel;
 	    if (dev->color_info.num_components <= 3)
-		pixel_out = (*dev_proc(dev, map_rgb_color))
-		    (dev, rgb[0], rgb[1], rgb[2]);
+		pixel_out = (*dev_proc(dev, map_rgb_color))(dev, rgb);
 	    else {
 		/* Convert RGB to CMYK. */
 		gx_color_value c = gx_max_color_value - rgb[0];
@@ -318,8 +329,9 @@ x_wrap_get_bits(gx_device * dev, int y, byte * str, byte ** actual_data)
 		gx_color_value y = gx_max_color_value - rgb[2];
 		gx_color_value k = (c < m ? min(c, y) : min(m, y));
 
-		pixel_out = (*dev_proc(dev, map_cmyk_color))
-		    (dev, c - k, m - k, y - k, k);
+                gx_color_value cmyk[4];
+                cmyk[0] = c - k; cmyk[1] = m - k; cmyk[2] = y - k; cmyk[3] = k;
+		pixel_out = (*dev_proc(dev, map_cmyk_color))(dev, cmyk);
 	    }
 	}
 	LINE_ACCUM(pixel_out, depth);
@@ -330,15 +342,17 @@ x_wrap_get_bits(gx_device * dev, int y, byte * str, byte ** actual_data)
     return code;
 }
 
-private int
+static int
 x_wrap_get_params(gx_device * dev, gs_param_list * plist)
 {
     gx_device *tdev;
     /* We assume that a get_params call has no side effects.... */
     gx_device_X save_dev;
     int ecode;
+    int code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     save_dev = *(gx_device_X *) tdev;
     if (tdev->is_open)
 	tdev->color_info = dev->color_info;
@@ -348,7 +362,7 @@ x_wrap_get_params(gx_device * dev, gs_param_list * plist)
     return ecode;
 }
 
-private int
+static int
 x_wrap_put_params(gx_device * dev, gs_param_list * plist)
 {
     gx_device *tdev;
@@ -356,7 +370,8 @@ x_wrap_put_params(gx_device * dev, gs_param_list * plist)
     const char *dname;
     int rcode, code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     /*
      * put_params will choke if we simply feed it the output of
      * get_params; we have to substitute color_info the same way.
@@ -377,7 +392,7 @@ x_wrap_put_params(gx_device * dev, gs_param_list * plist)
 /* Internal procedures */
 
 /* Get the target, creating it if necessary. */
-private int
+static int
 get_dev_target(gx_device ** ptdev, gx_device * dev)
 {
     gx_device *tdev = ((gx_device_forward *) dev)->target;
@@ -389,6 +404,7 @@ get_dev_target(gx_device ** ptdev, gx_device * dev)
 
 	if (code < 0)
 	    return 0;
+        check_device_separable(tdev);
 	gx_device_fill_in_procs(tdev);
 	gx_device_set_target((gx_device_forward *)dev, tdev);
 	x_clear_color_cache(dev);
@@ -398,12 +414,14 @@ get_dev_target(gx_device ** ptdev, gx_device * dev)
 }
 
 /* Copy parameters back from the target. */
-private int
+static int
 get_target_info(gx_device * dev)
 {
     gx_device *tdev;
+    int code;
 
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
 
 #define copy(m) dev->m = tdev->m;
 #define copy2(m) copy(m[0]); copy(m[1])
@@ -436,7 +454,7 @@ get_target_info(gx_device * dev)
 }
 
 /* Map a fake CMYK or black/white color to a real X color if necessary. */
-private gx_color_index
+static gx_color_index
 x_alt_map_color(gx_device * dev, gx_color_index color)
 {
     gx_device_X_wrapper *xdev = (gx_device_X_wrapper *) dev;
@@ -444,6 +462,7 @@ x_alt_map_color(gx_device * dev, gx_color_index color)
     gx_color_value rgb[3];
     gx_color_index cindex;
     int result;
+    int code;
 
     if (color == gx_no_color_index)
 	return color;
@@ -452,12 +471,13 @@ x_alt_map_color(gx_device * dev, gx_color_index color)
 	if (cindex != gx_no_color_index)
 	    return cindex;
     }
-    set_dev_target(tdev, dev);
+    if ((code = get_dev_target(&tdev, dev)) < 0)
+        return code;
     result = xdev->alt_map_color(dev, color, rgb);
     if (result >= 0)
 	cindex = result;
     else
-	cindex = dev_proc(tdev, map_rgb_color)(tdev, rgb[0], rgb[1], rgb[2]);
+	cindex = dev_proc(tdev, map_rgb_color)(tdev, rgb);
     if (color < 16)
 	((gx_device_X_wrapper *) dev)->color_cache[color] = cindex;
     return cindex;
@@ -466,14 +486,14 @@ x_alt_map_color(gx_device * dev, gx_color_index color)
 /* ---------------- CMYK procedures ---------------- */
 
 /* Device procedures */
-private dev_proc_open_device(x_cmyk_open);
-private dev_proc_put_params(x_cmyk_put_params);
-private dev_proc_map_cmyk_color(x_cmyk_map_cmyk_color);
+static dev_proc_open_device(x_cmyk_open);
+static dev_proc_put_params(x_cmyk_put_params);
+static dev_proc_map_cmyk_color(x_cmyk_map_cmyk_color);
 /* Extended device procedures */
-private dev_proc_map_color_rgb(x_cmyk_alt_map_color);
+static dev_proc_map_color_rgb(x_cmyk_alt_map_color);
 
 /* The device descriptor */
-private const gx_device_procs x_cmyk_procs = {
+static const gx_device_procs x_cmyk_procs = {
     x_cmyk_open,
     gx_forward_get_initial_matrix,
     x_forward_sync_output,
@@ -533,7 +553,7 @@ const gx_device_X_wrapper gs_x11cmyk8_device = {
 };
 
 /* Map a fake color to RGB. */
-private int
+static int
 x_cmyk_alt_map_color(gx_device * dev, gx_color_index color,
 		     gx_color_value rgb[3])
 {
@@ -553,7 +573,7 @@ x_cmyk_alt_map_color(gx_device * dev, gx_color_index color,
 }
 
 /* Set color mapping procedures */
-private void
+static void
 x_cmyk_set_procs(gx_device *dev)
 {
     if (dev->color_info.depth == 4) {
@@ -565,7 +585,7 @@ x_cmyk_set_procs(gx_device *dev)
 
 /* Device procedures */
 
-private int
+static int
 x_cmyk_open(gx_device *dev)
 {
     int code = x_wrap_open(dev);
@@ -575,7 +595,7 @@ x_cmyk_open(gx_device *dev)
     return code;
 }
 
-private int
+static int
 x_cmyk_put_params(gx_device * dev, gs_param_list * plist)
 {
     int code = x_wrap_put_params(dev, plist);
@@ -585,14 +605,13 @@ x_cmyk_put_params(gx_device * dev, gs_param_list * plist)
     return code;
 }
 
-private gx_color_index
-x_cmyk_map_cmyk_color(gx_device * dev,
-		      gx_color_value c, gx_color_value m, gx_color_value y,
-		      gx_color_value k)
+static gx_color_index
+x_cmyk_map_cmyk_color(gx_device * dev, const gx_color_value cv[])
 {
     int shift = dev->color_info.depth >> 2;
-    gx_color_index pixel = c >> (gx_color_value_bits - shift);
-
+    gx_color_index pixel = cv[0] >> (gx_color_value_bits - shift);
+    gx_color_value c, m, y, k;
+    c = cv[0]; m = cv[1]; y = cv[2]; k = cv[3];
     pixel = (pixel << shift) | (m >> (gx_color_value_bits - shift));
     pixel = (pixel << shift) | (y >> (gx_color_value_bits - shift));
     return (pixel << shift) | (k >> (gx_color_value_bits - shift));
@@ -601,10 +620,10 @@ x_cmyk_map_cmyk_color(gx_device * dev,
 /* ---------------- Black-and-white procedures ---------------- */
 
 /* Extended device procedures */
-private dev_proc_map_color_rgb(x_mono_alt_map_color);
+static dev_proc_map_color_rgb(x_mono_alt_map_color);
 
 /* The device descriptor */
-private const gx_device_procs x_mono_procs = {
+static const gx_device_procs x_mono_procs = {
     x_wrap_open,
     gx_forward_get_initial_matrix,
     x_forward_sync_output,
@@ -640,7 +659,7 @@ const gx_device_X_wrapper gs_x11mono_device = {
 };
 
 /* Map a fake color to RGB. */
-private int
+static int
 x_mono_alt_map_color(gx_device * dev, gx_color_index color,
 		     gx_color_value rgb[3])
 {
@@ -651,10 +670,10 @@ x_mono_alt_map_color(gx_device * dev, gx_color_index color,
 /* ---------------- 2- and 4-bit gray-scale procedures ---------------- */
 
 /* Extended device procedures */
-private dev_proc_map_color_rgb(x_gray_alt_map_color);
+static dev_proc_map_color_rgb(x_gray_alt_map_color);
 
 /* The device descriptor */
-private const gx_device_procs x_gray_procs = {
+static const gx_device_procs x_gray_procs = {
     x_wrap_open,
     gx_forward_get_initial_matrix,
     x_forward_sync_output,
@@ -699,7 +718,7 @@ const gx_device_X_wrapper gs_x11gray4_device = {
 };
 
 /* Map a fake color to RGB. */
-private int
+static int
 x_gray_alt_map_color(gx_device * dev, gx_color_index color,
 		     gx_color_value rgb[3])
 {
@@ -708,166 +727,31 @@ x_gray_alt_map_color(gx_device * dev, gx_color_index color,
     return -1;
 }
 
-#ifdef USE_BROKEN_X11ALPHA
-/* ---------------- Alpha procedures ---------------- */
-
-/* Device procedures */
-private dev_proc_map_color_rgb(x_alpha_map_color_rgb);
-private dev_proc_map_rgb_alpha_color(x_alpha_map_rgb_alpha_color);
-private dev_proc_copy_alpha(x_alpha_copy_alpha);
-/* Extended device procedures */
-private dev_proc_map_color_rgb(x_alpha_alt_map_color);
-
-/* The device descriptor */
-private const gx_device_procs x_alpha_procs = {
-    x_wrap_open,
-    gx_forward_get_initial_matrix,
-    x_forward_sync_output,
-    x_forward_output_page,
-    x_wrap_close,
-    gx_forward_map_rgb_color,
-    x_alpha_map_color_rgb,
-    x_wrap_fill_rectangle,
-    gx_default_tile_rectangle,
-    x_wrap_copy_mono,
-    x_forward_copy_color,
-    gx_default_draw_line,
-    x_forward_get_bits,
-    x_wrap_get_params,
-    x_wrap_put_params,
-    gx_forward_map_cmyk_color,
-    gx_forward_get_xfont_procs,
-    gx_forward_get_xfont_device,
-    x_alpha_map_rgb_alpha_color,
-    gx_forward_get_page_device,
-    gx_default_get_alpha_bits,
-	/*gx_default_copy_alpha */ x_alpha_copy_alpha
-};
-
-/* The instance is public. */
-const gx_device_X_wrapper gs_x11alpha_device = {
-    std_device_dci_alpha_type_body(gx_device_X_wrapper, &x_alpha_procs,
-	"x11alpha", &st_device_X_wrapper,
-	FAKE_RES * 85 / 10, FAKE_RES * 11,	/* x and y extent (nominal) */
-	FAKE_RES, FAKE_RES,	/* x and y density (nominal) */
-	3, 32, 255, 255, 256, 256, 4, 4),
-    X_WRAPPER_DATA(x_alpha_alt_map_color)
-};
-
-/* Map a fake color to RGB. */
-private int
-x_alpha_alt_map_color(gx_device * dev, gx_color_index color,
-		      gx_color_value rgb[3])
-{
-    return color & 0xffffff;	/* just remove alpha */
-}
-#endif
 /* Device procedures */
 
 /* We encode a complemented alpha value in the top 8 bits of the */
 /* device color. */
-private int
-x_alpha_map_color_rgb(gx_device * dev, gx_color_index color,
-		      gx_color_value prgb[3])
-{
-    return gx_forward_map_color_rgb(dev, color & 0xffffff, prgb);
-}
-private gx_color_index
+static gx_color_index
 x_alpha_map_rgb_alpha_color(gx_device * dev,
  gx_color_value r, gx_color_value g, gx_color_value b, gx_color_value alpha)
 {
-    gx_color_index color = gx_forward_map_rgb_color(dev, r, g, b);
+    gx_color_index color;
+    gx_color_value cv[3];
     byte abyte = alpha >> (gx_color_value_bits - 8);
-
+    cv[0] = r; cv[1] = g; cv[2] = b;
+    color = gx_forward_map_rgb_color(dev, cv);
     return (abyte == 0 ? (gx_color_index)0xff << 24 :
 	    ((gx_color_index) (abyte ^ 0xff) << 24) + color);
 }
 
-#ifdef USE_BROKEN_X11ALPHA
-private int
-x_alpha_copy_alpha(gx_device * dev, const unsigned char *base, int sourcex,
-		   int raster, gx_bitmap_id id, int x, int y, int w, int h,
-		   gx_color_index color, int depth)
-{
-    gx_device *tdev;
-    int xi, yi;
-    const byte *row = base;
-    gx_color_index base_color = color & 0xffffff;
-
-    /* We fake alpha by interpreting it as saturation, i.e., */
-    /* alpha = 0 is white, alpha = 15/15 is the full color. */
-    gx_color_value rgb[3];
-    gx_color_index shades[16];
-    int i;
-
-    set_dev_target(tdev, dev);
-    for (i = 0; i < 15; ++i)
-	shades[i] = gx_no_color_index;
-    shades[15] = base_color;
-    (*dev_proc(tdev, map_color_rgb)) (tdev, base_color, rgb);
-    /* Do the copy operation pixel-by-pixel. */
-    /* For the moment, if the base color has alpha in it, we ignore it. */
-    for (yi = y; yi < y + h; row += raster, ++yi) {
-	int prev_x = x;
-	gx_color_index prev_color = gx_no_color_index;
-	uint prev_alpha = 0x10;	/* not a possible value */
-
-	for (xi = x; xi < x + w; ++xi) {
-	    int sx = sourcex + xi - x;
-	    uint alpha2 = row[sx >> 1];
-	    uint alpha = (sx & 1 ? alpha2 & 0xf : alpha2 >> 4);
-	    gx_color_index a_color;
-
-	    if (alpha == prev_alpha)
-		continue;
-	    prev_alpha = alpha;
-	    if (alpha == 0)
-		a_color = gx_no_color_index;
-	    else
-		while ((a_color = shades[alpha]) == gx_no_color_index) {	/* Map the color now. */
-#define make_shade(v, alpha)\
-  (gx_max_color_value -\
-   ((gx_max_color_value - (v)) * (alpha) / 15))
-		    gx_color_value r = make_shade(rgb[0], alpha);
-		    gx_color_value g = make_shade(rgb[1], alpha);
-		    gx_color_value b = make_shade(rgb[2], alpha);
-
-#undef make_shade
-		    a_color = (*dev_proc(tdev, map_rgb_color)) (tdev, r, g, b);
-		    if (a_color != gx_no_color_index) {
-			shades[alpha] = a_color;
-			break;
-		    }
-		    /* Try a higher saturation.  (We know */
-		    /* the fully saturated color exists.) */
-		    alpha += (16 - alpha) >> 1;
-		}
-	    if (a_color != prev_color) {
-		if (prev_color != gx_no_color_index)
-		    (*dev_proc(tdev, fill_rectangle)) (tdev,
-						 prev_x, yi, xi - prev_x, 1,
-						       prev_color);
-		prev_x = xi;
-		prev_color = a_color;
-	    }
-	}
-	if (prev_color != gx_no_color_index)
-	    (*dev_proc(tdev, fill_rectangle)) (tdev,
-					       prev_x, yi, x + w - prev_x, 1,
-					       prev_color);
-    }
-    return 0;
-}
-#endif
-
 /* ---------------- Permuted RGB16/32 procedures ---------------- */
 
 /* Device procedures */
-private dev_proc_map_rgb_color(x_rg16x_map_rgb_color);
-private dev_proc_map_rgb_color(x_rg32x_map_rgb_color);
+static dev_proc_map_rgb_color(x_rg16x_map_rgb_color);
+static dev_proc_map_rgb_color(x_rg32x_map_rgb_color);
 /* Extended device procedures */
-private dev_proc_map_color_rgb(x_rg16x_alt_map_color);
-private dev_proc_map_color_rgb(x_rg32x_alt_map_color);
+static dev_proc_map_color_rgb(x_rg16x_alt_map_color);
+static dev_proc_map_color_rgb(x_rg32x_alt_map_color);
 
 /* The device descriptor */
 #define RGBX_PROCS(map_rgb_proc)\
@@ -894,7 +778,7 @@ private dev_proc_map_color_rgb(x_rg32x_alt_map_color);
     gx_default_get_alpha_bits,\
     gx_default_copy_alpha
 
-private const gx_device_procs x_rg16x_procs = {
+static const gx_device_procs x_rg16x_procs = {
     RGBX_PROCS(x_rg16x_map_rgb_color)
 };
 const gx_device_X_wrapper gs_x11rg16x_device = {
@@ -906,7 +790,7 @@ const gx_device_X_wrapper gs_x11rg16x_device = {
     X_WRAPPER_DATA(x_rg16x_alt_map_color)
 };
 
-private const gx_device_procs x_rg32x_procs = {
+static const gx_device_procs x_rg32x_procs = {
     RGBX_PROCS(x_rg32x_map_rgb_color)
 };
 const gx_device_X_wrapper gs_x11rg32x_device = {
@@ -919,27 +803,29 @@ const gx_device_X_wrapper gs_x11rg32x_device = {
 };
 
 /* Map RGB to a fake color. */
-private gx_color_index
-x_rg16x_map_rgb_color(gx_device * dev, gx_color_value r, gx_color_value g,
-		      gx_color_value b)
+static gx_color_index
+x_rg16x_map_rgb_color(gx_device * dev, const gx_color_value cv[])
 {
     /* Permute the colors to G5/B5/R6. */
+    gx_color_value r, g, b;
+    r = cv[0]; g = cv[1]; b = cv[2];
     return (r >> (gx_color_value_bits - 6)) +
 	((g >> (gx_color_value_bits - 5)) << 11) +
 	((b >> (gx_color_value_bits - 5)) << 6);
 }
-private gx_color_index
-x_rg32x_map_rgb_color(gx_device * dev, gx_color_value r, gx_color_value g,
-		      gx_color_value b)
+static gx_color_index
+x_rg32x_map_rgb_color(gx_device * dev, const gx_color_value cv[])
 {
     /* Permute the colors to G11/B10/R11. */
+    gx_color_value r, g, b;
+    r = cv[0]; g = cv[1]; b = cv[2];
     return (r >> (gx_color_value_bits - 11)) +
 	((gx_color_index)(g >> (gx_color_value_bits - 11)) << 21) +
 	((gx_color_index)(b >> (gx_color_value_bits - 10)) << 11);
 }
 
 /* Map a fake color to RGB. */
-private int
+static int
 x_rg16x_alt_map_color(gx_device * dev, gx_color_index color,
 		      gx_color_value rgb[3])
 {
@@ -948,7 +834,7 @@ x_rg16x_alt_map_color(gx_device * dev, gx_color_index color,
     rgb[2] = ((color >> 6) & 0x1f) * gx_max_color_value / 0x1f;
     return -1;
 }
-private int
+static int
 x_rg32x_alt_map_color(gx_device * dev, gx_color_index color,
 		      gx_color_value rgb[3])
 {
@@ -957,3 +843,20 @@ x_rg32x_alt_map_color(gx_device * dev, gx_color_index color,
     rgb[2] = ((color >> 11) & 0x3ff) * gx_max_color_value / 0x3ff;
     return -1;
 }
+
+#ifdef GS_DEVS_SHARED
+extern void gs_lib_register_device(const gx_device *dev);
+void
+gs_shared_init(void)
+{
+  gs_lib_register_device(&gs_x11_device);
+  gs_lib_register_device(&gs_x11alpha_device);
+  gs_lib_register_device(&gs_x11cmyk_device);
+  gs_lib_register_device(&gs_x11cmyk2_device);
+  gs_lib_register_device(&gs_x11cmyk4_device);
+  gs_lib_register_device(&gs_x11cmyk8_device);
+  gs_lib_register_device(&gs_x11gray2_device);
+  gs_lib_register_device(&gs_x11gray4_device);
+  gs_lib_register_device(&gs_x11mono_device);
+}
+#endif
