@@ -11,7 +11,7 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: gxclutil.c 8369 2007-11-15 07:22:43Z leonardo $ */
+/* $Id: gxclutil.c 8770 2008-05-22 18:06:22Z leonardo $ */
 /* Command list writing utilities. */
 
 #include "memory_.h"
@@ -224,7 +224,8 @@ cmd_put_list_op(gx_device_clist_writer * cldev, cmd_list * pcl, uint size)
 
     if (size + cmd_headroom > cldev->cend - dp) {
 	if ((cldev->error_code =
-	       cmd_write_buffer(cldev, cmd_opv_end_run)) != 0) {
+             cmd_write_buffer(cldev, cmd_opv_end_run)) != 0 ||
+            (size + cmd_headroom > cldev->cend - cldev->cnext)) {
 	    if (cldev->error_code < 0)
 		cldev->error_is_retryable = 0;	/* hard error */
 	    else {
@@ -246,7 +247,7 @@ cmd_put_list_op(gx_device_clist_writer * cldev, cmd_list * pcl, uint size)
 	    lprintf1("cmd_put_list_op error at 0x%lx\n", (ulong) pcl->tail);
 	}
 #endif
-	if_debug2('L', ", to id=%ld , offset=%ld", pcl->tail->id, pcl->tail->size);
+	if_debug2('L', ", to id=%ld , offset=%ld", pcl->tail->id, (long)pcl->tail->size);
 	pcl->tail->size += size;
     } else {
 	/* Skip to an appropriate alignment boundary. */
@@ -278,6 +279,25 @@ cmd_put_list_op(gx_device_clist_writer * cldev, cmd_list * pcl, uint size)
     cldev->cnext = dp + size;
     return dp;
 }
+
+/* Request a space in the buffer. 
+   Writes out the buffer if necessary.
+   Returns the size of available space. */
+int
+cmd_get_buffer_space(gx_device_clist_writer * cldev, gx_clist_state * pcls, uint size)
+{
+    cmd_list * pcl = &pcls->list;
+
+    if (size + cmd_headroom > cldev->cend - cldev->cnext) {
+	cldev->error_code = cmd_write_buffer(cldev, cmd_opv_end_run);
+	if (cldev->error_code < 0) {
+	    cldev->error_is_retryable = 0;	/* hard error */
+	    return cldev->error_code;
+	}
+    }
+    return cldev->cend - cldev->cnext - cmd_headroom;
+}
+
 #ifdef DEBUG
 byte *
 cmd_put_op(gx_device_clist_writer * cldev, gx_clist_state * pcls, uint size)
@@ -748,3 +768,16 @@ clist_rld_init(stream_RLD_state *ss)
     s_RLD_set_defaults_inline(ss);
     s_RLD_init_inline(ss);
 }
+
+/* Read a transformation matrix. */
+const byte *
+cmd_read_matrix(gs_matrix * pmat, const byte * cbp)
+{
+    stream s;
+
+    s_init(&s, NULL);
+    sread_string(&s, cbp, 1 + sizeof(*pmat));
+    sget_matrix(&s, pmat);
+    return cbp + stell(&s);
+}
+
