@@ -11,26 +11,28 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: inameidx.h 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: inameidx.h 8805 2008-06-26 19:17:37Z alexcher $ */
 /* Name index definitions */
 
 #ifndef inameidx_INCLUDED
 #  define inameidx_INCLUDED
 
-#include "gconfigv.h"		/* defines EXTEND_NAMES */
-
 /*
  * The name table machinery has two slightly different configurations:
  * a faster one that limits the total number of names to 64K and allows
- * names up to 16K in size, and a slightly slower one that limits
- * the total to 4M and restricts names to 256 characters.
+ * names up to 16K in size (EXTEND_NAMES == 0), and a slightly slower
+ * one that limits the total to 64K << EXTEND_NAMES and and restricts names
+ * to 16K >> EXTEND_NAMES. Max value of EXTEND_NAMES is 6, which corresponds
+ * to 4M names of up to to 256 characters.
  */
 #ifndef EXTEND_NAMES		/* # of bits beyond 16 */
-#  define EXTEND_NAMES 0
+#  define EXTEND_NAMES 4
 #endif
 
 /* Define the size of a name sub-table. */
-#define NT_LOG2_SUB_SIZE (8 + (EXTEND_NAMES / 2))
+/* With NT_LOG2_SUB_SIZE >= 10 the subtable goes into a large chunk, */
+/* which names_trace_finish() cannot handle. */
+# define NT_LOG2_SUB_SIZE (8 + (EXTEND_NAMES >= 2)) 
 # define NT_SUB_SIZE (1 << NT_LOG2_SUB_SIZE)
 # define NT_SUB_INDEX_MASK (NT_SUB_SIZE - 1)
 
