@@ -1,6 +1,6 @@
 /* Copyright (C) 2001-2006 Artifex Software, Inc.
    All Rights Reserved.
-  
+
    This software is provided AS-IS with no warranty, either express or
    implied.
 
@@ -11,9 +11,9 @@
    San Rafael, CA  94903, U.S.A., +1(415)492-9861, for further information.
 */
 
-/* $Id: sjpx_luratech.c 8022 2007-06-05 22:23:38Z giles $ */
+/* $Id: sjpx_luratech.c 8816 2008-07-03 18:25:52Z giles $ */
 /* JPXDecode filter implementation -- hooks in the Luratech JPEG2K CSDK */
- 
+
 #include "memory_.h"
 #include "malloc_.h"
 #include "gserrors.h"
@@ -37,8 +37,8 @@
 #endif
 ***/
 
-/* As with the /JBIG2Decode filter, we let the library do its  
-   memory management through malloc() etc. and rely on our release() 
+/* As with the /JBIG2Decode filter, we let the library do its
+   memory management through malloc() etc. and rely on our release()
    proc being called to deallocate state.
 */
 
@@ -50,16 +50,16 @@ private_st_jpxd_state(); /* creates a gc object for our state,
 /** callback for the codec library */
 
 /* memory allocation */
-private void * JP2_Callback_Conv
+static void * JP2_Callback_Conv
 s_jpx_alloc(long size, JP2_Callback_Param param)
 {
     void *result = malloc(size);
 
-    return result;   
+    return result;
 }
 
 /* memory free */
-private JP2_Error JP2_Callback_Conv
+static JP2_Error JP2_Callback_Conv
 s_jpx_free(void *ptr, JP2_Callback_Param param)
 {
     free(ptr);
@@ -68,9 +68,9 @@ s_jpx_free(void *ptr, JP2_Callback_Param param)
 }
 
 /* pass any available input to the library */
-private unsigned long JP2_Callback_Conv
+static unsigned long JP2_Callback_Conv
 s_jpxd_read_data(unsigned char *pucData,
-			    unsigned long ulPos, unsigned long ulSize, 
+			    unsigned long ulPos, unsigned long ulSize,
 			    JP2_Callback_Param param)
 {
     stream_jpxd_state *const state = (stream_jpxd_state *) param;
@@ -82,7 +82,7 @@ s_jpxd_read_data(unsigned char *pucData,
 }
 
 /* write decompressed data into our image buffer */
-private JP2_Error JP2_Callback_Conv
+static JP2_Error JP2_Callback_Conv
 s_jpxd_write_data(unsigned char * pucData,
 			       short sComponent,
 			       unsigned long ulRow,
@@ -117,7 +117,7 @@ s_jpxd_write_data(unsigned char * pucData,
     return cJP2_Error_OK;
 }
 
-private int
+static int
 s_jpxd_inbuf(stream_jpxd_state *state, stream_cursor_read * pr)
 {
     long in_size = pr->limit - pr->ptr;
@@ -138,7 +138,7 @@ s_jpxd_inbuf(stream_jpxd_state *state, stream_cursor_read * pr)
 	while (new_size < state->inbuf_fill + in_size)
 	    new_size = new_size << 1;
 
-	if_debug1('s', "[s]jpxd growing input buffer to %lu bytes\n", 
+	if_debug1('s', "[s]jpxd growing input buffer to %lu bytes\n",
 		new_size);
 	new = realloc(state->inbuf, new_size);
 	if (new == NULL) return gs_error_VMerror;
@@ -161,12 +161,16 @@ s_jpxd_inbuf(stream_jpxd_state *state, stream_cursor_read * pr)
    this involves allocating the stream and image structures, and
    initializing the decoder.
  */
-private int
+static int
 s_jpxd_init(stream_state * ss)
 {
     stream_jpxd_state *const state = (stream_jpxd_state *) ss;
 
-    state->jpx_memory = ss->memory ? ss->memory->non_gc_memory : gs_lib_ctx_get_non_gc_memory_t();
+    if (state->jpx_memory == NULL) {
+      state->jpx_memory = ss->memory ?
+		ss->memory->non_gc_memory :
+		gs_lib_ctx_get_non_gc_memory_t();
+    }
 
     state->handle = (JP2_Decomp_Handle)NULL;
 
@@ -188,7 +192,7 @@ s_jpxd_init(stream_state * ss)
 /* process a secton of the input and return any decoded data.
    see strimpl.h for return codes.
  */
-private int
+static int
 s_jpxd_process(stream_state * ss, stream_cursor_read * pr,
                  stream_cursor_write * pw, bool last)
 {
@@ -209,7 +213,7 @@ s_jpxd_process(stream_state * ss, stream_cursor_read * pr,
 	if (state->handle == (JP2_Decomp_Handle)NULL) {
 	    /* initialize decompressor */
 	    err = JP2_Decompress_Start(&state->handle,
-		/* memory allocator callbacks */ 
+		/* memory allocator callbacks */
 		s_jpx_alloc, (JP2_Callback_Param)state,
 		s_jpx_free,  (JP2_Callback_Param)state,
 		/* our read callback */
@@ -238,7 +242,7 @@ s_jpxd_process(stream_state * ss, stream_cursor_read * pr,
 	    state->ncomp = result;
 
 	    if_debug1('w', "[w]jpxd image has %d components\n", state->ncomp);
-	
+
 	    {
 		const char *cspace = "unknown";
 		err = JP2_Decompress_GetProp(state->handle,
@@ -307,7 +311,7 @@ s_jpxd_process(stream_state * ss, stream_cursor_read * pr,
 		    err= JP2_Decompress_GetProp(state->handle,
 			cJP2_Prop_Signed_Samples, &result, -1, (short)comp);
 		    if (err != cJP2_Error_OK) {
-			dlprintf2("Luratech JP2 error %d decoding " 
+			dlprintf2("Luratech JP2 error %d decoding "
 				"signedness of component %d\n", (int)err, comp);
 			return ERRC;
 		    }
@@ -324,12 +328,12 @@ s_jpxd_process(stream_state * ss, stream_cursor_read * pr,
 		}
 	    }
 	    if_debug3('w', "[w]jpxd decoding image at %ldx%ld"
-		" with %d bits per component\n", 
+		" with %d bits per component\n",
 		state->width, state->height, state->bpc);
 
 	}
 
-	if (state->handle != (JP2_Decomp_Handle)NULL && 
+	if (state->handle != (JP2_Decomp_Handle)NULL &&
 		state->image == NULL) {
 
 	    /* allocate our output buffer */
@@ -345,7 +349,7 @@ s_jpxd_process(stream_state * ss, stream_cursor_read * pr,
 		return ERRC;
 	    }
 	    err = JP2_Decompress_SetProp(state->handle,
-		cJP2_Prop_Output_Function, 
+		cJP2_Prop_Output_Function,
 		(JP2_Property_Value)s_jpxd_write_data);
 	    if (err != cJP2_Error_OK) {
 		dlprintf1("Luratech JP2 error %d setting output function\n", (int)err);
@@ -380,7 +384,7 @@ s_jpxd_process(stream_state * ss, stream_cursor_read * pr,
 /* stream release.
    free all our decoder state.
  */
-private void
+static void
 s_jpxd_release(stream_state *ss)
 {
     stream_jpxd_state *const state = (stream_jpxd_state *) ss;
@@ -395,10 +399,10 @@ s_jpxd_release(stream_state *ss)
 
 /* stream template */
 const stream_template s_jpxd_template = {
-    &st_jpxd_state, 
+    &st_jpxd_state,
     s_jpxd_init,
     s_jpxd_process,
-    1024, 1024,   /* min in and out buffer sizes we can handle 
+    1024, 1024,   /* min in and out buffer sizes we can handle
                      should be ~32k,64k for efficiency? */
     s_jpxd_release
 };
@@ -414,7 +418,7 @@ const stream_template s_jpxd_template = {
 private_st_jpxe_state();
 
 /* callback for uncompressed data input */
-private JP2_Error JP2_Callback_Conv
+static JP2_Error JP2_Callback_Conv
 s_jpxe_read(unsigned char *buffer, short component,
 		unsigned long row, unsigned long start,
 		unsigned long num, JP2_Callback_Param param)
@@ -450,7 +454,7 @@ s_jpxe_read(unsigned char *buffer, short component,
 }
 
 /* callback for compressed data output */
-private JP2_Error JP2_Callback_Conv
+static JP2_Error JP2_Callback_Conv
 s_jpxe_write(unsigned char *buffer,
 		unsigned long pos, unsigned long size,
 		JP2_Callback_Param param)
@@ -480,7 +484,7 @@ s_jpxe_write(unsigned char *buffer,
 	}
 	state->outbuf = new;
 	state->outsize *= 2;
-	if_debug1('s', "[s] jpxe output buffer resized to %lu bytes\n", 
+	if_debug1('s', "[s] jpxe output buffer resized to %lu bytes\n",
 		state->outsize);
     }
 
@@ -493,7 +497,7 @@ s_jpxe_write(unsigned char *buffer,
 }
 
 /* set defaults for user-configurable parameters */
-private void
+static void
 s_jpxe_set_defaults(stream_state *ss)
 {
     stream_jpxe_state *state = (stream_jpxe_state *)ss;
@@ -507,7 +511,7 @@ s_jpxe_set_defaults(stream_state *ss)
 }
 
 /* initialize the stream */
-private int
+static int
 s_jpxe_init(stream_state *ss)
 {
     stream_jpxe_state *state = (stream_jpxe_state *)ss;
@@ -594,25 +598,25 @@ s_jpxe_init(stream_state *ss)
     }
 
     /* set image parameters - the same for all components */
-    err = JP2_Compress_SetProp(state->handle, 
+    err = JP2_Compress_SetProp(state->handle,
 	cJP2_Prop_Width, state->width, -1, -1);
     if (err != cJP2_Error_OK) {
 	dlprintf1("Luratech JP2 error %d setting width\n", (int)err);
 	return ERRC;
     }
-    err = JP2_Compress_SetProp(state->handle, 
+    err = JP2_Compress_SetProp(state->handle,
 	cJP2_Prop_Height, state->height, -1, -1);
     if (err != cJP2_Error_OK) {
 	dlprintf1("Luratech JP2 error %d setting height\n", (int)err);
 	return ERRC;
     }
-    err = JP2_Compress_SetProp(state->handle, 
+    err = JP2_Compress_SetProp(state->handle,
 	cJP2_Prop_Bits_Per_Sample, state->bpc, -1, -1);
     if (err != cJP2_Error_OK) {
 	dlprintf1("Luratech JP2 error %d setting bits per sample\n", (int)err);
 	return ERRC;
     }
-  
+
     switch (state->colorspace) {
 	case gs_jpx_cs_gray: value = cJP2_Colorspace_Gray; break;
 	case gs_jpx_cs_rgb: value = cJP2_Colorspace_RGBa; break;
@@ -622,7 +626,7 @@ s_jpxe_init(stream_state *ss)
 		(int)state->colorspace);
 	    return ERRC;
     }
-    err = JP2_Compress_SetProp(state->handle, 
+    err = JP2_Compress_SetProp(state->handle,
 	cJP2_Prop_Extern_Colorspace, value, -1, -1);
     if (err != cJP2_Error_OK) {
 	dlprintf1("Luratech JP2 error %d setting colorspace\n", (int)err);
@@ -655,7 +659,7 @@ s_jpxe_init(stream_state *ss)
 
 /* process input and return any encoded data.
    see strimpl.h for return codes. */
-private int
+static int
 s_jpxe_process(stream_state *ss, stream_cursor_read *pr,
 		stream_cursor_write *pw, bool last)
 {
@@ -738,7 +742,7 @@ s_jpxe_process(stream_state *ss, stream_cursor_read *pr,
 }
 
 /* stream release. free all our state. */
-private void
+static void
 s_jpxe_release(stream_state *ss)
 {
     stream_jpxe_state *state = (stream_jpxe_state *)ss;
@@ -751,7 +755,7 @@ s_jpxe_release(stream_state *ss)
 	if_debug1('w', "[w]jpxe Luratech JP2 error %d"
 		" closing compression context", (int)err);
     }
-    
+
     /* free our own storage */
     free(state->outbuf);
     free(state->inbuf);
